@@ -2,11 +2,11 @@
 #'
 #' Functions for time series pre(post)processing, decomposition, modelling, prediction and accuracy assessment. The generated models and its yielded prediction errors can be used for benchmarking other time series prediction methods and for creating a demand for the refinement of such methods. For this purpose, benchmark data from prediction competitions may be used.
 #'
-#' @docType package
+# #' @docType package
 #' @name TSPred-package
 #' @author Rebecca Pontes Salles
 #'
 #' Maintainer: rebeccapsalles@acm.org
 #' @keywords package
 NULL # Instead of "_PACKAGE" to remove inclusion of \alias{forecast}
-# "_PACKAGE"
\ No newline at end of file
+"_PACKAGE"
